'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setExpectedAnnualActivity = exports.setActiveCurrency = exports.getActiveCurrency = exports.validateSupportNumber = exports.validatePersonIdv2 = exports.verifyExistingSePlayerWithToken = exports.verifyExistingSePlayer = exports.validatePhone = exports.validateEmail = exports.validateUsername = exports.setDetailsWithoutPassword = exports.setEmailPhone = exports.validateCpr = exports.lifetimeStats = exports.paymentStats = exports.changeNickname = exports.changeUsername = exports.tournamentOptIn = exports.bonusOptIn = exports.getOptOutInsByToken = exports.optOutChoices = exports.optOut = exports.optIn = exports.getOptInOuts = exports.removeTag = exports.addTag = exports.getDisplayPages = exports.getTags = exports.requestActivationCode = exports.activate = exports.resetPassword = exports.requestPasswordReset = exports.updatePlayerTac = exports.signOut = exports.createSSOToken = exports.signInWithCode = exports.signInV2 = exports.signIn = exports.changePassword = exports.userInfo = exports.update = exports.signUpWithToken = exports.signUpWithCode = exports.signUpV2 = exports.signUp = undefined;

var _utils = require('./utils');

/**
 * @typedef UserModel
 * @type {object}
 * @property {string} Username
 * @property {string} Password
 * @property {string} Email
 * @property {string} NickName
 * @property {string} BirthDate
 * @property {string} FirstName
 * @property {string} LastName
 * @property {string} Address1
 * @property {string} Address2
 * @property {string} City
 * @property {string} Zip
 * @property {string} Region
 * @property {string} Country
 * @property {string} PhoneNumber
 * @property {string} MobilePhoneNumber
 * @property {string} Language
 * @property {string} [Gender=Male]
 * @property {string} [Currency=Default]
 * @property {boolean} [ReceiveNewsletters=true]
 * @property {boolean} [ReceiveOffers=true]
 * @property {string} PromoCode
 * @property {string} AffiliateTag
 */

/**
 * @typedef SignInModel
 * @property {string} Username
 * @property {string} Password
 * @property {string} [Platform=Desktop]
 * @property {string} [OperatingSystem]
 * @property {string} [Browser]
 */

/**
 * Register a new player in the system and creates a wallet in the supplied currency, or in the default currency if none is supplied
 * @param {UserModel} userInfo
 * @returns {int} Player ID
 */
var signUp = exports.signUp = function signUp(userInfo) {
  return (0, _utils.post)('/player/signup', userInfo);
};

/**
 * Register a new player in the system and creates a wallet in the supplied currency, or in the default currency if none is supplied
 * @param {UserModel} userInfo
 * @returns {Object} Object containing Player ID and Issues
 */
var signUpV2 = exports.signUpV2 = function signUpV2(userInfo) {
  return (0, _utils.post)('/player/signup/v2', userInfo);
};

/**
 * Register a new player in the system using a auth code provided via third party auth service and creates a wallet in the supplied currency, or in the default currency if none is supplied.
 * @param {UserModel} userInfo
 * @returns {Object} Object containing Player ID and Issues
 */
var signUpWithCode = exports.signUpWithCode = function signUpWithCode(userInfo) {
  return (0, _utils.post)('/player/signup/code', userInfo);
};

var signUpWithToken = exports.signUpWithToken = function signUpWithToken(userInfo) {
  return (0, _utils.post)('/player/signup/token', userInfo);
};

/**
 * Update the current players info, the players current password is required to authenticate the change
 * @param {UserModel} user
 * @param {string} playerSessionID
 */
var update = exports.update = function update(user, playerSessionID) {
  return (0, _utils.postProtected)('/player/update', playerSessionID, user);
};

/**
 * Get all saved user details for the currently authenticated user
 * @param {string} playerSessionID
 * @returns {UserModel}
 */
var userInfo = exports.userInfo = function userInfo(playerSessionID) {
  return (0, _utils.getProtected)('/player/user-info', playerSessionID);
};

/**
 * Change player password
 * @param {Object} passwords an object contains curernt password and new password
 * @param {string} passwords.CurrentPassword Current Password
 * @param {string} passwords.NewPassword New password
 * @param {string} playerSessionID
 */
var changePassword = exports.changePassword = function changePassword(passwords, playerSessionID) {
  return (0, _utils.postProtected)('/player/change-password', playerSessionID, passwords);
};

/**
 * Authenticates a player and creates a new session. Failed sign in attemps will cause the client to be rate limited, ie he can not try to sign in again until some time has passed. The time between subsequent signins is calculated using the following formula (n - 1) ^ 2 seconds, where n is the number of attempts The rate limit is reset on successfully login and is tracked by ip and username
 * @param {SignInModel} user
 * @returns {string} Session ID
 */
var signIn = exports.signIn = function signIn(user) {
  return (0, _utils.post)('/player/signin', user);
};

/**
 * Authenticates a player and creates a new session and TacVersionAccepted. Failed sign in attemps will cause the client to be rate limited, ie he can not try to sign in again until some time has passed. The time between subsequent signins is calculated using the following formula (n - 1) ^ 2 seconds, where n is the number of attempts The rate limit is reset on successfully login and is tracked by ip and username
 * @param {SignInModel} user
 * @returns {string} Session ID
 */
var signInV2 = exports.signInV2 = function signInV2(user) {
  return (0, _utils.post)('/player/signin/v2', user);
};

/**
 * Authenticates a player and creates a new session and TacVersionAccepted. Failed sign in attemps will cause the client to be rate limited, ie he can not try to sign in again until some time has passed. The time between subsequent signins is calculated using the following formula (n - 1) ^ 2 seconds, where n is the number of attempts The rate limit is reset on successfully login and is tracked by ip and username
 * @param {SignInModel} user
 * @returns {string} Session ID
 */
var signInWithCode = exports.signInWithCode = function signInWithCode(user) {
  return (0, _utils.post)('/player/signin/code', user);
};

/**
 * Creates a single sign on token that can be used by third party products like casino games to authenticate with the back office. The token will only be valid for a short time but at least for five minutes.
 * @param {string} playerSessionID
 * @param {('Default'|'MetricGaming'|'QuickFire'|'ISoftBet'|'SBTech'|'Yggdrasil')} tokenType
 * @returns {string}
 */
var createSSOToken = exports.createSSOToken = function createSSOToken(playerSessionID) {
  var tokenType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'Default';
  return (0, _utils.postProtected)('/player/create-sso-token?tokenType=' + tokenType, playerSessionID);
};

/**
 * Invalidates the current session
 * @param {string} playerSessionID
 */
var signOut = exports.signOut = function signOut(playerSessionID) {
  return (0, _utils.postProtected)('/player/signout', playerSessionID);
};

/**
 * Update player Tac
 * @param {string} tacVersionAccepted
 */
var updatePlayerTac = exports.updatePlayerTac = function updatePlayerTac(tacVersionAccepted, playerSessionID) {
  return (0, _utils.fetchJSON)('/player/update-player-tac?tacVersionAccepted=' + tacVersionAccepted, {
    headers: {
      'X-Player-Session-Id': playerSessionID
    }
  });
};

/**
 * Request password reset
 * @param {string} UsernameOrEmail
 */
var requestPasswordReset = exports.requestPasswordReset = function requestPasswordReset(UsernameOrEmail) {
  return (0, _utils.post)('/player/request-password-reset', { UsernameOrEmail: UsernameOrEmail });
};

/**
 * Resets the players password provided a password reset token and a new password. The token will be destroyed upon a successfull reset.
 * @typedef ResetPasswordModel
 * @type {object}
 * @property {string} UsernameOrEmail
 * @property {string} Token
 * @property {string} NewPassword
 * @param {ResetPasswordModel} resetPasswordModel
 */
var resetPassword = exports.resetPassword = function resetPassword(resetPasswordModel) {
  return (0, _utils.post)('/player/reset-password', resetPasswordModel);
};

/**
 * Activate the player account using a code sent to the player by email or sms.
 * @param {string} UsernameOrEmail
 */
var activate = exports.activate = function activate(UsernameOrEmail, Code, DeviceDetails) {
  return (0, _utils.post)('/player/activate', { UsernameOrEmail: UsernameOrEmail, Code: Code, DeviceDetails: DeviceDetails });
};

/**
 * Request a new activation code for a player, the code will be sent either by email or sms
 * @param {string} UsernameOrEmail
 */
var requestActivationCode = exports.requestActivationCode = function requestActivationCode(UsernameOrEmail) {
  return (0, _utils.post)('/player/request-activation-code', { UsernameOrEmail: UsernameOrEmail });
};

/**
 * Get a list of all tags currently assigned to the player
 * @param {string} playerSessionID
 */
var getTags = exports.getTags = function getTags(playerSessionID) {
  return (0, _utils.getProtected)('/player/tags', playerSessionID);
};

/**
 * Get all not displayed player login pages
 * @param {string} playerSessionID
 */
var getDisplayPages = exports.getDisplayPages = function getDisplayPages(playerSessionID) {
  return (0, _utils.getProtected)('/player/display-pages', playerSessionID);
};

/**
 * Add an existing player tag by its name (identifier) to a player
 * @param {string} Tag
 * @param {string} playerSessionID
 */
var addTag = exports.addTag = function addTag(Tag, playerSessionID) {
  return (0, _utils.postProtected)('/player/add-tag-to-player', playerSessionID, { Tag: Tag });
};

/**
 * Remove an existing player tag by its name (identifier) from a player
 * @param {string} Tag
 * @param {string} playerSessionID
 */
var removeTag = exports.removeTag = function removeTag(Tag, playerSessionID) {
  return (0, _utils.postProtected)('/player/remove-tag-from-player', playerSessionID, { Tag: Tag });
};

/**
 * Get a list of all possible opt in/outs with current player status
 * @param {string} playerSessionID Session ID
 */
var getOptInOuts = exports.getOptInOuts = function getOptInOuts(playerSessionID) {
  return (0, _utils.getProtected)('/player/opt-in-outs', playerSessionID);
};

/**
 * Opt in player to pre-defined type
 * @param {string} playerSessionID
 */
var optIn = exports.optIn = function optIn(playerSessionID, Type) {
  return (0, _utils.postProtected)('/player/opt-in', playerSessionID, { Type: Type });
};

/**
 * Opt out player from pre-defined type
 * @param {string} playerSessionID
 */
var optOut = exports.optOut = function optOut(playerSessionID, Type) {
  return (0, _utils.postProtected)('/player/opt-out', playerSessionID, { Type: Type });
};

/**
 * Opts in the player by the optIns param. This will opt out the player from the abscent opt ins in the array.
 * @param {*} optOutToken
 * @param {*} optIns
 */
var optOutChoices = exports.optOutChoices = function optOutChoices(optOutToken, optIns) {
  return (0, _utils.post)('/player/opt-out-choices', { OptOutToken: optOutToken, OptIns: optIns });
};

/**
 * Get a list of all possible opt in/outs for a player
 * @param {*} optOutToken
 */
var getOptOutInsByToken = exports.getOptOutInsByToken = function getOptOutInsByToken(optOutToken) {
  return (0, _utils.get)('/player/opt-out-ins?unsubToken=' + optOutToken);
};

/**
 * Opt in player to bonus which requires that
 * @param {string} PlayerId
 * @param {string} BonusId
 * @param {string} playerSessionID
 */
var bonusOptIn = exports.bonusOptIn = function bonusOptIn(PlayerId, BonusId, playerSessionID) {
  return (0, _utils.postProtected)('/player/bonus-opt-in', playerSessionID, { PlayerId: PlayerId, BonusId: BonusId });
};

/**
 * Opt in player to tournament which requires that
 * @param {string} PlayerId
 * @param {string} TournamentIdentifier
 */
var tournamentOptIn = exports.tournamentOptIn = function tournamentOptIn(PlayerId, TournamentIdentifier) {
  return (0, _utils.post)('/player/tournament-opt-in', { PlayerId: PlayerId, TournamentIdentifier: TournamentIdentifier });
};

/**
 * Change the login/username of player
 * @param {string} Username
 * @param {string} playerSessionID
 */
var changeUsername = exports.changeUsername = function changeUsername(Username, playerSessionID) {
  return (0, _utils.postProtected)('/player/change-username', playerSessionID, { Username: Username });
};

/**
 * Change the Nickname of player
 * @param {string} nickname
 * @param {string} playerSessionID
 */
var changeNickname = exports.changeNickname = function changeNickname(Nickname, playerSessionID) {
  return (0, _utils.postProtected)('/player/change-nickname', playerSessionID, {
    Nickname: Nickname
  });
};

/**
 * Get information about a players deposits and withdraws
 * @param {string} playerSessionID Session ID
 */
var paymentStats = exports.paymentStats = function paymentStats(playerSessionID) {
  return (0, _utils.getProtected)('/player/payment-stats', playerSessionID);
};

var lifetimeStats = exports.lifetimeStats = function lifetimeStats(playerSessionID) {
  return (0, _utils.getProtected)('/player/lifetime-stats', playerSessionID);
};

/**
 * Validate cpr
 * @param {string} cpr CPR
 */
var validateCpr = exports.validateCpr = function validateCpr(cpr) {
  return (0, _utils.get)('/player/validate-cpr?cpr=' + cpr);
};

/**
 * Set new e-mail, phone & mobile. Email is always required.
 * @param {string} Email
 * @param {string} Phone
 * @param {string} Mobile
 * @param {string} playerSessionID
 */
var setEmailPhone = exports.setEmailPhone = function setEmailPhone(playerSessionID, Email, Phone, Mobile) {
  return (0, _utils.postProtected)('/player/set-email-phone', playerSessionID, {
    Email: Email,
    Phone: Phone,
    Mobile: Mobile
  });
};

/**
 * Set new e-mail, phone, mobile & first name without password.
 * @param {string} Email
 * @param {string} Phone
 * @param {string} Mobile
 * @param {string} FirstName
 * @param {string} playerSessionID
 */
var setDetailsWithoutPassword = exports.setDetailsWithoutPassword = function setDetailsWithoutPassword(playerSessionID, Email, Phone, Mobile, FirstName) {
  return (0, _utils.postProtected)('/player/set-details-without-password', playerSessionID, {
    Email: Email,
    Phone: Phone,
    Mobile: Mobile,
    FirstName: FirstName
  });
};

/**
 * Validate username
 * @param {string} username
 */
var validateUsername = exports.validateUsername = function validateUsername(username, jurisdiction) {
  return (0, _utils.get)('/player/validate-username?username=' + username + '&jurisdiction=' + jurisdiction);
};

/**
 * Validate email
 * @param {string} email
 */
var validateEmail = exports.validateEmail = function validateEmail(email, jurisdiction) {
  return (0, _utils.get)('/player/validate-email?email=' + email + '&jurisdiction=' + jurisdiction);
};

/**
 * Validate phone
 * @param {string} phone
 */
var validatePhone = exports.validatePhone = function validatePhone(phone, jurisdiction) {
  return (0, _utils.get)('/player/validate-phone?phoneNumber=' + phone + '&jurisdiction=' + jurisdiction);
};

var verifyExistingSePlayer = exports.verifyExistingSePlayer = function verifyExistingSePlayer(verifySePlayerModel, playerSessionID) {
  return (0, _utils.postProtected)('/player/verify-existing-se-player', playerSessionID, verifySePlayerModel);
};

var verifyExistingSePlayerWithToken = exports.verifyExistingSePlayerWithToken = function verifyExistingSePlayerWithToken(verifySePlayerModel, playerSessionID) {
  return (0, _utils.postProtected)('/player/verify-existing-se-player/token', playerSessionID, verifySePlayerModel);
};

var validatePersonIdv2 = exports.validatePersonIdv2 = function validatePersonIdv2(personId, jurisdiction) {
  return (0, _utils.get)('/player/validate-personid/v2?personId=' + personId + '&jurisdiction=' + jurisdiction);
};

var validateSupportNumber = exports.validateSupportNumber = function validateSupportNumber(supportNumber, jurisdiction) {
  return (0, _utils.get)('/player/validate-support-number?supportNumber=' + supportNumber + '&jurisdiction=' + jurisdiction);
};

/**
 * GET /player/active-currencyGet the display currency used for the player
 * @param {*} playerSessionID
 * @returns string
 */
var getActiveCurrency = exports.getActiveCurrency = function getActiveCurrency(playerSessionID) {
  return (0, _utils.getProtected)('/player/active-currency', playerSessionID);
};

/**
 * Set the active display currency for the player, balances will be shown in this currency.
 * @param {*} currency
 * @param {*} playerSessionID
 * @returns
 */
var setActiveCurrency = exports.setActiveCurrency = function setActiveCurrency(currency, playerSessionID) {
  return (0, _utils.postProtected)('/player/active-currency?currency=' + currency, playerSessionID);
};

/**
 * Set the expected annual activity for the player.
 * @param {number} expectedAnnualActivityFrom
 * @param {number} expectedAnnualActivityTo
 * @param {string} playerSessionID
 * @returns
 */
var setExpectedAnnualActivity = exports.setExpectedAnnualActivity = function setExpectedAnnualActivity(playerSessionID, expectedAnnualActivityFrom, expectedAnnualActivityTo) {
  return (0, _utils.postProtected)('/kyc/source-of-wealth/v2', playerSessionID, {
    IncomeFromValue: expectedAnnualActivityFrom,
    IncomeToValue: expectedAnnualActivityTo,
    Type: 'ExpectedAnnualActivity'
  });
};

exports.default = {
  signUp: signUp,
  signUpV2: signUpV2,
  signUpWithCode: signUpWithCode,
  signUpWithToken: signUpWithToken,
  update: update,
  userInfo: userInfo,
  changePassword: changePassword,
  signIn: signIn,
  signInV2: signInV2,
  signInWithCode: signInWithCode,
  createSSOToken: createSSOToken,
  signOut: signOut,
  updatePlayerTac: updatePlayerTac,
  requestPasswordReset: requestPasswordReset,
  resetPassword: resetPassword,
  activate: activate,
  requestActivationCode: requestActivationCode,
  getTags: getTags,
  addTag: addTag,
  removeTag: removeTag,
  getOptInOuts: getOptInOuts,
  optIn: optIn,
  optOut: optOut,
  optOutChoices: optOutChoices,
  bonusOptIn: bonusOptIn,
  tournamentOptIn: tournamentOptIn,
  changeUsername: changeUsername,
  changeNickname: changeNickname,
  paymentStats: paymentStats,
  lifetimeStats: lifetimeStats,
  getOptOutInsByToken: getOptOutInsByToken,
  validateCpr: validateCpr,
  setEmailPhone: setEmailPhone,
  setDetailsWithoutPassword: setDetailsWithoutPassword,
  verifyExistingSePlayer: verifyExistingSePlayer,
  verifyExistingSePlayerWithToken: verifyExistingSePlayerWithToken,
  validateUsername: validateUsername,
  validateEmail: validateEmail,
  validatePhone: validatePhone,
  validatePersonIdv2: validatePersonIdv2,
  validateSupportNumber: validateSupportNumber,
  getDisplayPages: getDisplayPages,
  getActiveCurrency: getActiveCurrency,
  setActiveCurrency: setActiveCurrency,
  setExpectedAnnualActivity: setExpectedAnnualActivity
};