'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cancelTransaction = exports.getBingoTransactions = exports.getFantasyTransactions = exports.getSportsbookTransactions = exports.getGamePlayTransactions = exports.getPayments = exports.getTransaction = exports.getTransactions = undefined;

var _utils = require('./utils');

/**
 * Get a list of all transactions for the authenticated player
 * @param {string} playerSessionID Session ID
 * @param {number} max The maximum number of transactions to retrieve
 * @param {number} offset Number of transactions to skip, ie if set to 30 then the first 30 transactions are skipped
 * @param {('Payment'|'Game'|'All')} transactionType The type of the transactions to retrieve
 */
var getTransactions = exports.getTransactions = function getTransactions(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var transactionType = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'Payment';
  return (0, _utils.getProtected)('/transaction?max=' + max + '&offset=' + offset + '&transactionType=' + transactionType, playerSessionID);
};

/**
 * Get a detailed list of all "sub parts" in a transaction. The sub transactions will show exactly which wallets / bonuses contributed to the transaction.
 * @param {string} playerSessionID
 * @param {string} transactionId
 */
var getTransaction = exports.getTransaction = function getTransaction(playerSessionID, transactionId) {
  return (0, _utils.getProtected)('/transaction/' + transactionId, playerSessionID);
};

/**
 * Get all payments
 * @param {string} playerSessionID Session ID
 * @param {number} max The maximum number of transactions to retrieve
 * @param {number} offset Number of transactions to skip, ie if set to 30 then the first 30 transactions are skipped
 * @param {('withdraw'|'deposit'|'')} type The type of the transactions to retrieve
 */
var getPayments = exports.getPayments = function getPayments(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var type = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  return (0, _utils.getProtected)('/transaction/payments?max=' + max + '&offset=' + offset + '&type=' + type, playerSessionID);
};

/**
 * Get all game play transactions
 * @param {string} playerSessionID Session ID
 * @param {number} max The maximum number of transactions to retrieve
 * @param {number} offset Number of transactions to skip, ie if set to 30 then the first 30 transactions are skipped
 */
var getGamePlayTransactions = exports.getGamePlayTransactions = function getGamePlayTransactions(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  return (0, _utils.getProtected)('/transaction/gameplay?max=' + max + '&offset=' + offset, playerSessionID);
};

/**
 * Get all sportsbook transactions
 * @param {string} playerSessionID Session ID
 * @param {number} max The maximum number of transactions to retrieve
 * @param {number} offset Number of transactions to skip, ie if set to 30 then the first 30 transactions are skipped
 */
var getSportsbookTransactions = exports.getSportsbookTransactions = function getSportsbookTransactions(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  return (0, _utils.getProtected)('/transaction/sportsbookbets?max=' + max + '&offset=' + offset, playerSessionID);
};

/**
 * Get all fantasy transactions
 * @param {string} playerSessionID Session ID
 * @param {number} max The maximum number of transactions to retrieve
 * @param {number} offset Number of transactions to skip, ie if set to 30 then the first 30 transactions are skipped
 */
var getFantasyTransactions = exports.getFantasyTransactions = function getFantasyTransactions(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  return (0, _utils.getProtected)('/transaction/fantasybets?max=' + max + '&offset=' + offset, playerSessionID);
};

/**
 *
 * @param {string} playerSessionID
 * @param {number} max
 * @param {number} offset
 * @returns
 */
var getBingoTransactions = exports.getBingoTransactions = function getBingoTransactions(playerSessionID) {
  var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  return (0, _utils.getProtected)('/transaction/bingogames?max=' + max + '&offset=' + offset, playerSessionID);
};

/**
 * Cancel a pending transaction, currently only valid for withdraws
 * @param {string} playerSessionID
 * @param {string} transactionId
 */
var cancelTransaction = exports.cancelTransaction = function cancelTransaction(playerSessionID, transactionId) {
  return (0, _utils.postProtected)('/transaction/cancel/' + transactionId, playerSessionID);
};

exports.default = {
  getTransactions: getTransactions,
  getTransaction: getTransaction,
  getPayments: getPayments,
  getGamePlayTransactions: getGamePlayTransactions,
  getSportsbookTransactions: getSportsbookTransactions,
  getFantasyTransactions: getFantasyTransactions,
  getBingoTransactions: getBingoTransactions,
  cancelTransaction: cancelTransaction
};